# Inspeqtor

[![DOI](https://zenodo.org/badge/894394996.svg)](https://doi.org/10.5281/zenodo.17748401)

<div align="center">
<img src="https://raw.githubusercontent.com/PorametPat/inspeqtor/refs/heads/main/docs/assets/inspeqtor_logo.svg" alt="logo" style="width: 100px"></img>
</div>

## Greeting 🖖

We aim to be a Data-efficient Framework for Characterization and Calibration of Quantum Device. As performing experiment and take data from the quantum device could be expensive. We would like to squeeze every drop of information from the data.

> ⚠️ This package and document are still under development. Please proceed with caution.

## Installation

To install `inspeqtor` for local devlopement, you have to pull the repository locally via

```bash
git clone https://github.com/PorametPat/inspeqtor.git
```

Using `uv`,
Then install it using

``` bash
uv sync
```

Or `pip` via

``` bash
pip install ./<PATH>
```

where the `<PATH>` is the path to the local `inspeqtor` repository that you cloned.

## How to contribute?

Thank you for your interest in contributing to `inspeqtor`! Please refer to our [developer note](https://porametpat.github.io/inspeqtor/latest/dev/#how-to-contribute) for guidelines.

## Documentation

Check the [documentation](https://porametpat.github.io/inspeqtor/latest/) for published materials. To generate documentation locally, follow this [guide](https://porametpat.github.io/inspeqtor/latest/dev/#documentation).

## Citation

If you find our library to be useful and would like to cite our work, please use the following,

```bibtex
@software{Pathumsoot_inspeqtor,
    author = {Pathumsoot, Poramet},
    doi = {10.5281/zenodo.17748402},
    license = {BSD-3-Clause},
    title = {{inspeqtor}},
    url = {https://github.com/PorametPat/inspeqtor}
}
```
